2022-07-14 Version: 2.0.21
- Add UpdateAutoSqlOptimizeStatus API.

2022-07-13 Version: 2.0.20
- Add UpdateAutoSqlOptimizeStatus API.

2022-05-20 Version: 2.0.18
- Dbgateway support delete api.


2022-04-28 Version: 2.0.17
- EventCenter support event name filter.


2022-04-01 Version: 2.0.16
- FIX GetAsyncErrorRequestStatResult PARAM TYPE.


2022-03-18 Version: 2.0.15
- FIX GetRequestDiagnosisPage PARAM TYPE.


2022-02-25 Version: 2.0.10
- FIX GetRequestDiagnosisPage PARAM TYPE.


2022-01-27 Version: 2.0.7
- Supported query optimize open API.

2021-12-28 Version: 2.0.6
- Fixed useless variables.

2021-12-06 Version: 2.0.5
- Fixed useless variables.

2021-11-17 Version: 2.0.4
- Fixed useless variables.

2021-11-04 Version: 2.0.3
- Fixed useless variables.

2021-11-03 Version: 2.0.2
- Fixed useless variables.

2021-11-02 Version: 2.0.1
- Fixed useless variables.

2021-03-31 Version: 2.0.0
- Generated python 2020-01-16 for DAS.

2020-11-30 Version: 1.1.0
- Support new API GetAutonomousNotifyEvents and GetAutonomousNotifyEventDetail.

